==> ejc-middlemeasurement-impl-3.0.0-20220412.090131-33-sources.jar: com/ejianc/business/middlemeasurement/bean/CreditorsrightsEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.CreditorsrightsdetailEntity;
/**
 * 债权情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_creditorsrights")
public class CreditorsrightsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="deadline")
    private java.util.Date deadline; // 截至时间 
    @TableField(value="operational")
    private java.math.BigDecimal operational; // 经营性债权
    @TableField(value="revolving_fund")
    private java.math.BigDecimal revolvingFund; // 备用金
    @TableField(value="margin")
    private java.math.BigDecimal margin; // 保证金
    @TableField(value="total")
    private java.math.BigDecimal total; // 债权合计
    
    
//    @TableField(exist=false)
//    @SubEntity(serviceName="creditorsrightsdetailService")
//    private List<CreditorsrightsdetailEntity> creditorsrightsdetailEntities = new ArrayList<>(); // 债权情况子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 截至时间 
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 截至时间 
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 经营性债权
     */
    public java.math.BigDecimal getOperational() {
        return operational;
    }

    /**
     * 经营性债权
     */
    public void setOperational(java.math.BigDecimal operational) {
        this.operational = operational;
    }
    /**
     * 备用金
     */
    public java.math.BigDecimal getRevolvingFund() {
        return revolvingFund;
    }

    /**
     * 备用金
     */
    public void setRevolvingFund(java.math.BigDecimal revolvingFund) {
        this.revolvingFund = revolvingFund;
    }
    /**
     * 保证金
     */
    public java.math.BigDecimal getMargin() {
        return margin;
    }

    /**
     * 保证金
     */
    public void setMargin(java.math.BigDecimal margin) {
        this.margin = margin;
    }
    /**
     * 债权合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 债权合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }

    /**
     * 债权情况子表
    public List<CreditorsrightsdetailEntity> getCreditorsrightsdetailEntities() {
        return creditorsrightsdetailEntities;
    }*/

    /**
     * 债权情况子表

    public void setCreditorsrightsdetailEntities(List<CreditorsrightsdetailEntity> creditorsrightsdetailEntities) {
        this.creditorsrightsdetailEntities = creditorsrightsdetailEntities;
    }*/


}

==> ejc-middlemeasurement-impl-3.0.0-20240327.063749-530-sources.jar: com/ejianc/business/middlemeasurement/bean/CreditorsrightsEntity.java <==
package com.ejianc.business.middlemeasurement.bean;

import java.util.Date;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.middlemeasurement.bean.CreditorsrightsdetailEntity;
/**
 * 债权情况
 * 
 * @author generator
 * 
 */
 @TableName("ejc_middlemeasurement_creditorsrights")
public class CreditorsrightsEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private java.lang.String billCode; // 单据编号
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="project_id")
    private java.lang.Long projectId; // 项目id
    @TableField(value="project_name")
    private java.lang.String projectName; // 项目名称
    @TableField(value="org_id")
    private java.lang.Long orgId; // 所属组织id
    @TableField(value="org_name")
    private java.lang.String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private java.lang.Long projectDepartmentId; // 项目部id
    @TableField(value="deadline")
    private java.util.Date deadline; // 截至时间 
    @TableField(value="operational")
    private java.math.BigDecimal operational; // 经营性债权
    @TableField(value="revolving_fund")
    private java.math.BigDecimal revolvingFund; // 备用金
    @TableField(value="margin")
    private java.math.BigDecimal margin; // 保证金
    @TableField(value="total")
    private java.math.BigDecimal total; // 债权合计
    @TableField(value = "save_time")
    private java.util.Date saveTime;

    public Date getSaveTime() {
        return saveTime;
    }

    public void setSaveTime(Date saveTime) {
        this.saveTime = saveTime;
    }
    
//    @TableField(exist=false)
//    @SubEntity(serviceName="creditorsrightsdetailService")
//    private List<CreditorsrightsdetailEntity> creditorsrightsdetailEntities = new ArrayList<>(); // 债权情况子表
    

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 项目id
     */
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 所属组织id
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 所属组织id
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 所属组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 所属组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目部id
     */
    public java.lang.Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    /**
     * 项目部id
     */
    public void setProjectDepartmentId(java.lang.Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    /**
     * 截至时间 
     */
    public java.util.Date getDeadline() {
        return deadline;
    }

    /**
     * 截至时间 
     */
    public void setDeadline(java.util.Date deadline) {
        this.deadline = deadline;
    }
    /**
     * 经营性债权
     */
    public java.math.BigDecimal getOperational() {
        return operational;
    }

    /**
     * 经营性债权
     */
    public void setOperational(java.math.BigDecimal operational) {
        this.operational = operational;
    }
    /**
     * 备用金
     */
    public java.math.BigDecimal getRevolvingFund() {
        return revolvingFund;
    }

    /**
     * 备用金
     */
    public void setRevolvingFund(java.math.BigDecimal revolvingFund) {
        this.revolvingFund = revolvingFund;
    }
    /**
     * 保证金
     */
    public java.math.BigDecimal getMargin() {
        return margin;
    }

    /**
     * 保证金
     */
    public void setMargin(java.math.BigDecimal margin) {
        this.margin = margin;
    }
    /**
     * 债权合计
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 债权合计
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }

    /**
     * 债权情况子表
    public List<CreditorsrightsdetailEntity> getCreditorsrightsdetailEntities() {
        return creditorsrightsdetailEntities;
    }*/

    /**
     * 债权情况子表

    public void setCreditorsrightsdetailEntities(List<CreditorsrightsdetailEntity> creditorsrightsdetailEntities) {
        this.creditorsrightsdetailEntities = creditorsrightsdetailEntities;
    }*/


}
